@@ -164,7 +164,7 @@ class FedFSv1(FedAvg):
             config["timeout"] = str(self.t_max)
 
         # Fit instructions
-        fit_ins = (parameters, config)
+        fit_ins = FitIns(parameters, config)
 
         # Return client/config pairs
         return [(client, fit_ins) for client in clients]
@@ -251,26 +251,30 @@ class FedFSv1(FedAvg):
 
         # Convert results
         weights_results = [
-            (parameters_to_weights(parameters), num_examples)
-            for client, (parameters, num_examples, _, _) in results
+            (parameters_to_weights(fit_res.parameters), fit_res.num_examples)
+            for client, fit_res in results
         ]
         weights_prime = aggregate(weights_results)
 
         # Track contributions to the global model
         for client, fit_res in results:
             cid = client.cid
-            contribution: Tuple[int, int, int] = (rnd, fit_res[1], fit_res[2])
+            contribution: Tuple[int, int, int] = (
+                rnd,
+                fit_res.num_examples,
+                fit_res.num_examples_ceil,
+            )
             if cid not in self.contributions.keys():
                 self.contributions[cid] = []
             self.contributions[cid].append(contribution)
 
         self.durations = []
-        for client, (_, num_examples, num_examples_ceil, fit_duration) in results:
+        for client, fit_res in results:
             cid_duration = (
                 client.cid,
-                fit_duration,
-                num_examples,
-                num_examples_ceil,
+                fit_res.fit_duration,
+                fit_res.num_examples,
+                fit_res.num_examples_ceil,
             )
             self.durations.append(cid_duration)
 
@@ -292,4 +296,9 @@ class FedFSv1(FedAvg):
             # Not enough results for aggregation
             return None
 
-        return weighted_loss_avg([evaluate_res for _, evaluate_res in results])
+        return weighted_loss_avg(
+            [
+                (evaluate_res.num_examples, evaluate_res.loss, evaluate_res.accuracy)
+                for client, evaluate_res in results
+            ]
+        )
